
#ifndef VTKPVADAPTORSCTH_EXPORT_H
#define VTKPVADAPTORSCTH_EXPORT_H

#ifdef VTKPVADAPTORSCTH_STATIC_DEFINE
#  define VTKPVADAPTORSCTH_EXPORT
#  define VTKPVADAPTORSCTH_NO_EXPORT
#else
#  ifndef VTKPVADAPTORSCTH_EXPORT
#    ifdef AdaptorsCTH_EXPORTS
        /* We are building this library */
#      define VTKPVADAPTORSCTH_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVADAPTORSCTH_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVADAPTORSCTH_NO_EXPORT
#    define VTKPVADAPTORSCTH_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVADAPTORSCTH_DEPRECATED
#  define VTKPVADAPTORSCTH_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVADAPTORSCTH_DEPRECATED_EXPORT
#  define VTKPVADAPTORSCTH_DEPRECATED_EXPORT VTKPVADAPTORSCTH_EXPORT VTKPVADAPTORSCTH_DEPRECATED
#endif

#ifndef VTKPVADAPTORSCTH_DEPRECATED_NO_EXPORT
#  define VTKPVADAPTORSCTH_DEPRECATED_NO_EXPORT VTKPVADAPTORSCTH_NO_EXPORT VTKPVADAPTORSCTH_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVADAPTORSCTH_NO_DEPRECATED
#    define VTKPVADAPTORSCTH_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVAdaptorsCTHModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVADAPTORSCTH_EXPORT_H */
